#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-lsp-server
version:              1.0.15
visibility:           public
id:                   dhall-lsp-server-1.0.15-F2lFEGghilqKTlYI0Ih9rz
key:                  dhall-lsp-server-1.0.15-F2lFEGghilqKTlYI0Ih9rz
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriel Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  0850153998c6ae98fb6d604f75d878c7
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-8.10.5/site-local/dhall-lsp-server-1.0.15
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dhall-lsp-server-1.0.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/dhall-lsp-server-1.0.15
hs-libraries:         HSdhall-lsp-server-1.0.15-F2lFEGghilqKTlYI0Ih9rz
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    aeson-pretty-0.8.8-3aCNsqOVx5w7giic7jdZv7 base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1
    data-default-0.7.1.1-5u8NwVJ9HGT30K0bkKsBOX
    dhall-1.39.0-9hwObYnBp2lA0AH9VF4Rc9
    dhall-json-1.7.7-2YQUGn13wmqEt3MC0ZGvHv directory-1.3.6.0
    filepath-1.4.2.1 haskell-lsp-0.24.0.0-EwNiEEXu3F04ZCReHHfurQ
    hslogger-1.3.1.0-4ZvjEIYEuqKInhLQNg26B3
    lens-5.0.1-9j09gzxg2dR5Wmd3U39g28
    megaparsec-9.0.1-CgNxKp13Re58VqY3iga6b3 mtl-2.2.2
    network-uri-2.6.4.1-4m8gp52oIfHLdE9VhQrWxs
    prettyprinter-1.7.0-D28lGbKBr8A22zyggdsd0d
    rope-utf16-splay-0.3.2.0-4BO3wv3HTjC6do6mxk98HB text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    uri-encode-1.5.0.7-6JTrF8Giaa98AsdSOirsjM

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

